package
Version:
v1.0.6
Opens a new window with list of versions in this module.
Published: Feb 10, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func SaveStructToExcel(path string, data interface{}) error
SaveStructToExcel 将结构体数组保存为 Excel 文件,标题由结构体字段名生成。
Source Files
¶
Click to show internal directories.
Click to hide internal directories.